@@ -90,7 +90,7 @@ const GSETTINGS_SCHEMAS_DIR: &str = "/usr/share/glib-2.0/schemas";
 fn main() {
     let c: Cargo = Cargo::parse();
 
-    let target_env = std::env::var("CARGO_TARGET_DIR").unwrap_or("target".into());
+    let target_env = std::env::var("CARGO_TARGET_DIR").unwrap_or_else(|_| "target".into());
     let target_dir = PathBuf::new().join(target_env);
 
     match c.gra {
@@ -315,7 +315,7 @@ fn flatpak(target_dir: PathBuf, arguments: Flatpak) {
         flatpak_build_rel,
         gra_gen.to_str().unwrap(),
         &project_descriptor.app.id,
-        arguments.arch.as_ref().map(|a| format!("--arch {}", a)).unwrap_or("".into())
+        arguments.arch.as_ref().map(|a| format!("--arch {}", a)).unwrap_or_else(|| "".into())
     );
 
     let mut c = Command::new("flatpak-builder");
